#!/bin/sh
#
# System initialization script: /etc/rc.d/rc.S:  
#
PATH=/sbin:/usr/sbin:/bin:/usr/bin

# Enable swapping:

if [ -x /sbin/swapon ]; then
/sbin/swapon -a 2>/dev/null
fi

# Start update:

if [ -x /sbin/update ]; then
/sbin/update 
fi

# Test to see if the root partition is read-only, like it ought to be:

READWRITE=no
if echo -n >> "Testing filesystem status"; then
rm -f "Testing filesystem status"
READWRITE=yes
echo
echo "ERROR!  You should have 'ro' in the 'linux.bat' file: root=/dev/hdb3 ro"
echo "Please restart your computer and change it." 
echo
while :
do
read ERROR
done
fi

# Check the integrity of all filesystems:
if [ ! $READWRITE = yes ]; then

fsck -A -p -y

# If there was a serious fsck failure:
 if [ $? -gt 1 ]; then
  echo
  echo "******************************************************************************"
  echo "ERROR! fsck returned error from /etc/rc.d/rc.S script ..."
  echo "******************************************************************************"
  echo 
  echo "You can get into your system by using the smaller linux system."
  echo "From the smaller system you can mount this system."
  echo
  echo "C:\veclinux > ram.bat   <Boot small linux system>"
  echo 
  echo "# mount -t ext2 /dev/hdb3 /DOS"
  echo "# mc /DOS"
  echo
  echo "******************************************************************************"
  echo "The system is read-only now, remount it read-write and try to fix the problem." 
  echo "# mount -n -o remount,rw /"
  echo "******************************************************************************"
  echo
  echo "******************************************************************************"
  echo "Press [Enter] no password required to login, or press [Ctrl] D to reboot."
  echo "******************************************************************************"
  echo
  sulogin /dev/tty0
  reboot -f
 fi
fi

# Remount the root filesystem in read-write mode:

  echo "Remounting root device with read-write enabled."
  mount -w -n -o remount /
  if [ $? -gt 0 ]; then
  echo
  echo "Attempt to remount root device as read-write failed!"
  echo
  echo "Maybe there's a problem with the /bin/mount command."
  echo "mount -w -n -o remount /   <You should have this in /etc/rc.d/rc.S>"
  echo 
  echo "You can get into this system by using the smaller linux system."
  echo "From the smaller system you can mount this loop system."
  echo
  echo "C:\veclinux > ram.bat            <Boot small linux system>"
  echo "# mc                           <Press [F1] key for help>"
  echo
  echo "****************************************************************************"
  echo "Press [Enter] no password required to login, or press [Ctrl] D to reboot."
  echo "****************************************************************************"
  echo
  echo "This system is read-only, try to remount it read-write."
  echo "mount -w -n -o remount /"
  echo 
  sulogin /dev/tty0
  reboot -f
fi

# Remove /etc/mtab so that mount will create it with a root entry.
rm -f /etc/mtab /etc/nologin /etc/shutdownpid  

# Mount file systems in /etc/fstab (and create an entry for /)
# but not NFS because TCP/IP is not yet configured.
mount -avt nonfs

# Remove any pids in /var/run.
rm -f /var/run/*pid 

# Remove contents of /var/run/utmp.
cat /dev/null >/var/run/utmp  

# Configure the system clock.
# Set system time from BIOS time.

#if [ -x /sbin/hwclock ]; then
#/sbin/hwclock --hctosys 
#fi

# Setup the /etc/issue and /etc/motd to reflect the current kernel level:
# THESE WIPE ANY CHANGES YOU MAKE TO /ETC/ISSUE AND /ETC/MOTD WITH EACH
# BOOT. COMMENT THEM OUT IF YOU WANT TO MAKE CUSTOM VERSIONS.

/usr/local/bin/linux_logo -c > /etc/issue
echo >> /etc/issue
echo "Vector-Linux `uname -r`" > /etc/motd

# If you have a PNP modem or any PNP device, you may need to use pnpdump 
# and isapnp to get it setup.
#
# pnpdump -c > /etc/isapnp.conf   <Create /etc/isapnp.conf file>
# isapnp /etc/isapnp.conf
#
# Read the docs in /usr/doc/isapnptools.
# pnpdump isapnp isapnp.conf   <Man pages>

#if [ -x /sbin/isapnp -a -s /etc/isapnp.conf ]; then
#/sbin/isapnp /etc/isapnp.conf
#fi

# This loads any kernel modules that are needed. These might be required to
# use your CD-ROM drive, bus mouse, ethernet card, or other optional hardware.
# Look at the /etc/rc.d/rc.modules file for modules to load.

if [ -x /etc/rc.d/rc.modules ]; then
/etc/rc.d/rc.modules
fi

# Initialize PCMCIA devices:
#
# This requires the 'rc.pcmcia' script which is part of the 'pcmcia' package.

if [ `dmesg | fgrep -q PCMCIA` $? = 0 ] && [ -x /etc/rc.d/rc.pcmcia ] && [ -s /lib/modules/`uname -r`/pcmcia/pcmcia_core.o ]; then
/etc/rc.d/rc.pcmcia start
fi

# Run serial port setup script:
# (CAREFUL! This can make some systems hang if the rc.serial script isn't
# set up correctly. If this happens, you may have to edit the file from a
# boot disk)
#
# Run 'comset' to create a /etc/rc.d/rc.serial for your modem device.
# comset

if [ -x /etc/rc.d/rc.serial ]; then
/etc/rc.d/rc.serial
fi

# Update all the shared library links automatically.
ldconfig -q

# This script is for your soundcard setup of io, interupt, dma addresses.

if [ -x /etc/rc.d/rc.soundcard ]; then
 . /etc/rc.d/rc.soundcard
fi

